.. _linear_elasticity-examples-index:

linear_elasticity
=================

.. toctree::
   :maxdepth: 2

   dispersion_analysis.py <linear_elasticity-dispersion_analysis>
   elastic_contact_planes.py <linear_elasticity-elastic_contact_planes>
   elastic_contact_sphere.py <linear_elasticity-elastic_contact_sphere>
   elastic_shifted_periodic.py <linear_elasticity-elastic_shifted_periodic>
   elastodynamic.py <linear_elasticity-elastodynamic>
   elastodynamic_identification.py <linear_elasticity-elastodynamic_identification>
   its2D_1.py <linear_elasticity-its2D_1>
   its2D_2.py <linear_elasticity-its2D_2>
   its2D_3.py <linear_elasticity-its2D_3>
   its2D_4.py <linear_elasticity-its2D_4>
   its2D_5.py <linear_elasticity-its2D_5>
   its2D_interactive.py <linear_elasticity-its2D_interactive>
   linear_elastic.py <linear_elasticity-linear_elastic>
   linear_elastic_damping.py <linear_elasticity-linear_elastic_damping>
   linear_elastic_iga.py <linear_elasticity-linear_elastic_iga>
   linear_elastic_interactive.py <linear_elasticity-linear_elastic_interactive>
   linear_elastic_probes.py <linear_elasticity-linear_elastic_probes>
   linear_elastic_tractions.py <linear_elasticity-linear_elastic_tractions>
   linear_elastic_up.py <linear_elasticity-linear_elastic_up>
   linear_viscoelastic.py <linear_elasticity-linear_viscoelastic>
   material_nonlinearity.py <linear_elasticity-material_nonlinearity>
   mixed_mesh.py <linear_elasticity-mixed_mesh>
   modal_analysis.py <linear_elasticity-modal_analysis>
   modal_analysis_declarative.py <linear_elasticity-modal_analysis_declarative>
   multi_node_lcbcs.py <linear_elasticity-multi_node_lcbcs>
   nodal_lcbcs.py <linear_elasticity-nodal_lcbcs>
   prestress_fibres.py <linear_elasticity-prestress_fibres>
   seismic_load.py <linear_elasticity-seismic_load>
   shell10x_cantilever.py <linear_elasticity-shell10x_cantilever>
   shell10x_cantilever_interactive.py <linear_elasticity-shell10x_cantilever_interactive>
   truss_bridge.py <linear_elasticity-truss_bridge>
   truss_bridge3d.py <linear_elasticity-truss_bridge3d>
   two_bodies_contact.py <linear_elasticity-two_bodies_contact>
   wedge_mesh.py <linear_elasticity-wedge_mesh>
